==> jc-1.4.0.tar.gz: soot/jimple/toolkits/scalar/LocalCreation.h <==
// public class soot.jimple.toolkits.scalar.LocalCreation

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 6ec6adda3514ee80 soot_jimple_toolkits_scalar_LocalCreation

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jimple_toolkits_scalar_LocalCreation_H_
#define _JC_soot_jimple_toolkits_scalar_LocalCreation_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Set$object;
struct _jc_soot_Local$object;
struct _jc_soot_Type$object;
struct _jc_soot_util_Chain$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_scalar_LocalCreation$sub_refs	_jc_soot_jimple_toolkits_scalar_LocalCreation$sub_refs;
typedef struct _jc_soot_jimple_toolkits_scalar_LocalCreation$sub_nonrefs	_jc_soot_jimple_toolkits_scalar_LocalCreation$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_scalar_LocalCreation$refs	_jc_soot_jimple_toolkits_scalar_LocalCreation$refs;
typedef struct _jc_soot_jimple_toolkits_scalar_LocalCreation$nonrefs	_jc_soot_jimple_toolkits_scalar_LocalCreation$nonrefs;
typedef struct _jc_soot_jimple_toolkits_scalar_LocalCreation$object	_jc_soot_jimple_toolkits_scalar_LocalCreation$object;

typedef struct _jc_soot_jimple_toolkits_scalar_LocalCreation$fields_struct	_jc_soot_jimple_toolkits_scalar_LocalCreation$fields_struct;
typedef const struct _jc_soot_jimple_toolkits_scalar_LocalCreation$vmethods	_jc_soot_jimple_toolkits_scalar_LocalCreation$vmethods;
typedef const struct _jc_soot_jimple_toolkits_scalar_LocalCreation$vtable	_jc_soot_jimple_toolkits_scalar_LocalCreation$vtable;
typedef const struct _jc_soot_jimple_toolkits_scalar_LocalCreation$vtype	_jc_soot_jimple_toolkits_scalar_LocalCreation$vtype;

// Class fields structure
struct _jc_soot_jimple_toolkits_scalar_LocalCreation$fields_struct {
	struct _jc_java_lang_String$object	*DEFAULT__5fPREFIX;
};
extern _jc_soot_jimple_toolkits_scalar_LocalCreation$fields_struct _jc_soot_jimple_toolkits_scalar_LocalCreation$class_fields;

// Constructors
extern void _jc_soot_jimple_toolkits_scalar_LocalCreation$method$_init$326b03e9ec7889c4(_jc_env *, struct _jc_soot_jimple_toolkits_scalar_LocalCreation$object *, struct _jc_object *);
extern void _jc_soot_jimple_toolkits_scalar_LocalCreation$method$_init$e469f65e2e9f00d7(_jc_env *, struct _jc_soot_jimple_toolkits_scalar_LocalCreation$object *, struct _jc_object *, struct _jc_java_lang_String$object *);

// Virtual methods
extern struct _jc_object *_jc_soot_jimple_toolkits_scalar_LocalCreation$method$newLocal$6ee026e3f2189853(_jc_env *, struct _jc_soot_jimple_toolkits_scalar_LocalCreation$object *, struct _jc_java_lang_String$object *, struct _jc_soot_Type$object *);
extern struct _jc_object *_jc_soot_jimple_toolkits_scalar_LocalCreation$method$newLocal$674d691d2c9d57f9(_jc_env *, struct _jc_soot_jimple_toolkits_scalar_LocalCreation$object *, struct _jc_soot_Type$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_scalar_LocalCreation$method_info$newLocal$6ee026e3f2189853;
extern _jc_method _jc_soot_jimple_toolkits_scalar_LocalCreation$method_info$newLocal$674d691d2c9d57f9;

// Virtual methods structure
struct _jc_soot_jimple_toolkits_scalar_LocalCreation$vmethods {
	struct _jc_object	*(*newLocal$6ee026e3f2189853)(_jc_env *, struct _jc_soot_jimple_toolkits_scalar_LocalCreation$object *, struct _jc_java_lang_String$object *, struct _jc_soot_Type$object *);
	struct _jc_object	*(*newLocal$674d691d2c9d57f9)(_jc_env *, struct _jc_soot_jimple_toolkits_scalar_LocalCreation$object *, struct _jc_soot_Type$object *);
};

// Vtable
struct _jc_soot_jimple_toolkits_scalar_LocalCreation$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_toolkits_scalar_LocalCreation$vmethods	soot_jimple_toolkits_scalar_LocalCreation;
};

// Vtype
struct _jc_soot_jimple_toolkits_scalar_LocalCreation$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_scalar_LocalCreation$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_scalar_LocalCreation$sub_refs {
	struct _jc_java_lang_String$object	*prefix;
	struct _jc_object	*locals;
	struct _jc_object	*localChain;
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_scalar_LocalCreation$refs {
    _jc_soot_jimple_toolkits_scalar_LocalCreation$sub_refs	soot_jimple_toolkits_scalar_LocalCreation;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_scalar_LocalCreation$sub_nonrefs {
	jint	counter;
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_scalar_LocalCreation$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_toolkits_scalar_LocalCreation$sub_nonrefs	soot_jimple_toolkits_scalar_LocalCreation;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_scalar_LocalCreation$object {
	_jc_soot_jimple_toolkits_scalar_LocalCreation$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_scalar_LocalCreation$vtype	*vtype;
	_jc_soot_jimple_toolkits_scalar_LocalCreation$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_scalar_LocalCreation$vtype _jc_soot_jimple_toolkits_scalar_LocalCreation$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_scalar_LocalCreation, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_scalar_LocalCreation$class_object;

#endif	/* _JC_soot_jimple_toolkits_scalar_LocalCreation_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/toolkits/scalar/LocalCreation.h <==
// public class soot.jimple.toolkits.scalar.LocalCreation

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 6ec6adda3514ee80 soot_jimple_toolkits_scalar_LocalCreation

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jimple_toolkits_scalar_LocalCreation_H_
#define _JC_soot_jimple_toolkits_scalar_LocalCreation_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Set$object;
struct _jc_soot_Local$object;
struct _jc_soot_Type$object;
struct _jc_soot_util_Chain$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_scalar_LocalCreation$sub_refs	_jc_soot_jimple_toolkits_scalar_LocalCreation$sub_refs;
typedef struct _jc_soot_jimple_toolkits_scalar_LocalCreation$sub_nonrefs	_jc_soot_jimple_toolkits_scalar_LocalCreation$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_scalar_LocalCreation$refs	_jc_soot_jimple_toolkits_scalar_LocalCreation$refs;
typedef struct _jc_soot_jimple_toolkits_scalar_LocalCreation$nonrefs	_jc_soot_jimple_toolkits_scalar_LocalCreation$nonrefs;
typedef struct _jc_soot_jimple_toolkits_scalar_LocalCreation$object	_jc_soot_jimple_toolkits_scalar_LocalCreation$object;

typedef struct _jc_soot_jimple_toolkits_scalar_LocalCreation$fields_struct	_jc_soot_jimple_toolkits_scalar_LocalCreation$fields_struct;
typedef const struct _jc_soot_jimple_toolkits_scalar_LocalCreation$vmethods	_jc_soot_jimple_toolkits_scalar_LocalCreation$vmethods;
typedef const struct _jc_soot_jimple_toolkits_scalar_LocalCreation$vtable	_jc_soot_jimple_toolkits_scalar_LocalCreation$vtable;
typedef const struct _jc_soot_jimple_toolkits_scalar_LocalCreation$vtype	_jc_soot_jimple_toolkits_scalar_LocalCreation$vtype;

// Class fields structure
struct _jc_soot_jimple_toolkits_scalar_LocalCreation$fields_struct {
	struct _jc_java_lang_String$object	*DEFAULT__5fPREFIX;
};
extern _jc_soot_jimple_toolkits_scalar_LocalCreation$fields_struct _jc_soot_jimple_toolkits_scalar_LocalCreation$class_fields;

// Constructors
extern void _jc_soot_jimple_toolkits_scalar_LocalCreation$method$_init$326b03e9ec7889c4(_jc_env *, struct _jc_soot_jimple_toolkits_scalar_LocalCreation$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_toolkits_scalar_LocalCreation$method$_init$e469f65e2e9f00d7(_jc_env *, struct _jc_soot_jimple_toolkits_scalar_LocalCreation$object *, struct _jc_object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_object *_jc_soot_jimple_toolkits_scalar_LocalCreation$method$newLocal$6ee026e3f2189853(_jc_env *, struct _jc_soot_jimple_toolkits_scalar_LocalCreation$object *, struct _jc_java_lang_String$object *, struct _jc_soot_Type$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_soot_jimple_toolkits_scalar_LocalCreation$method$newLocal$674d691d2c9d57f9(_jc_env *, struct _jc_soot_jimple_toolkits_scalar_LocalCreation$object *, struct _jc_soot_Type$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_scalar_LocalCreation$method_info$newLocal$6ee026e3f2189853;
extern _jc_method _jc_soot_jimple_toolkits_scalar_LocalCreation$method_info$newLocal$674d691d2c9d57f9;

// Virtual methods structure
struct _jc_soot_jimple_toolkits_scalar_LocalCreation$vmethods {
	struct _jc_object	*(*newLocal$6ee026e3f2189853)(_jc_env *, struct _jc_soot_jimple_toolkits_scalar_LocalCreation$object *, struct _jc_java_lang_String$object *, struct _jc_soot_Type$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*newLocal$674d691d2c9d57f9)(_jc_env *, struct _jc_soot_jimple_toolkits_scalar_LocalCreation$object *, struct _jc_soot_Type$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_toolkits_scalar_LocalCreation$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_toolkits_scalar_LocalCreation$vmethods	soot_jimple_toolkits_scalar_LocalCreation;
};

// Vtype
struct _jc_soot_jimple_toolkits_scalar_LocalCreation$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_scalar_LocalCreation$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_scalar_LocalCreation$sub_refs {
	struct _jc_java_lang_String$object	*prefix;
	struct _jc_object	*locals;
	struct _jc_object	*localChain;
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_scalar_LocalCreation$refs {
    _jc_soot_jimple_toolkits_scalar_LocalCreation$sub_refs	soot_jimple_toolkits_scalar_LocalCreation;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_scalar_LocalCreation$sub_nonrefs {
	jint	counter;
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_scalar_LocalCreation$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_toolkits_scalar_LocalCreation$sub_nonrefs	soot_jimple_toolkits_scalar_LocalCreation;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_scalar_LocalCreation$object {
	_jc_soot_jimple_toolkits_scalar_LocalCreation$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_scalar_LocalCreation$vtype	*vtype;
	_jc_soot_jimple_toolkits_scalar_LocalCreation$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_scalar_LocalCreation$vtype _jc_soot_jimple_toolkits_scalar_LocalCreation$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_scalar_LocalCreation, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_scalar_LocalCreation$class_object;

#endif	/* _JC_soot_jimple_toolkits_scalar_LocalCreation_H_ */
